from .Threshold import ThresholdBase as Threshold
from .Chargecontroller import ChargeControllerBase as ChargeController
from .Prediction import PredictionBase as Prediction
from .hoursselection import Hoursselectionbase as Hoursselection

# from .Models import (
#     CHARGERSTATES
# )


import setuptools

setuptools.setup(
    name="peaqevcore",
    version="0.0.15",
    author="Magnus Eldén",
    description="Core types for peaqev car charging",
    packages=["peaqevcore"],
    install_requires=['pytest', 'datetime', 'statistics'],
)   